@@ -1,5 +1,6 @@
 import kate
 
+from kate_settings_plugins import kate_plugins_settings
 from utils import insertText
 
 TEXT_JQUERY = """<script type="text/javascript">
@@ -14,6 +15,6 @@ TEXT_JQUERY = """<script type="text/javascript">
 """
 
 
-@kate.action('JQuery Ready', shortcut='Ctrl+J', menu='Edit')
+@kate.action(**kate_plugins_settings['insertReady'])
 def insertReady():
     insertText(TEXT_JQUERY, start_in_current_column=True)
