@@ -9,12 +9,14 @@ try:
     from pyte_plugins.autocomplete.autocomplete import *
 except ImportError:
     pass
+
 from pyte_plugins.djte_plugins.class_plugins import *
 from pyte_plugins.djte_plugins.text_plugins import *
 from pyte_plugins.text_plugins import *
 from pyte_plugins.check_plugins.parse_plugins import *
+
 try:
-    from pyte_plugins.check_plugins.refresh_marks_plugins import *
+    from pyte_plugins.check_plugins.cheack_all_plugins import *
 except ImportError:
     pass
 try:
@@ -26,4 +28,3 @@ try:
     from pyte_plugins.check_plugins.pyflakes_plugins import *
 except ImportError:
     pass
-
