@@ -2,8 +2,6 @@ import kate
 
 from utils import is_mymetype_python
 
-old_marks = {}
-
 
 def showOk(message="Ok", time=3, icon='dialog-ok'):
     kate.gui.popup(message, time, icon='dialog-ok', minTextWidth=200)
@@ -17,18 +15,8 @@ def generateErrorMessage(error):
     return message
 
 
-def removeOldMarks(key_mark, doc):
-    # Delete previous errors
-    mark_iface = doc.markInterface()
-    if key_mark in old_marks:
-        for mark in old_marks[key_mark]:
-            mark_iface.removeMark(mark.line, mark.type)
-    old_marks[key_mark] = []
-
-
 def showErrors(message, errors, key_mark, doc, time=10, icon='dialog-warning',
-               key_line='line', max_errors=3):
-    removeOldMarks(key_mark, doc)
+               key_line='line', max_errors=3, show_popup=True):
     mark_iface = doc.markInterface()
     for i, error in enumerate(errors):
         if i < max_errors:
@@ -39,8 +27,8 @@ def showErrors(message, errors, key_mark, doc, time=10, icon='dialog-warning',
         mark.line = error[key_line] - 1
         mark.type = mark_iface.Error
         mark_iface.setMark(mark.line, mark.type)
-        old_marks[key_mark].append(mark)
-    kate.gui.popup(message, time, icon, minTextWidth=200)
+    if show_popup:
+        kate.gui.popup(message, time, icon, minTextWidth=200)
 
 
 def canCheckDocument(doc, text_plain=False):
